import { DateRange } from 'src/types/shared/dateRange'

/**
 * This describes aditional information about a project.
 * to display when listing the project on the portfolio page.
 * At minimum, the title should be specified.
 */
export type ProjectListingInfo = {
  /**[Supports Markdown]
   * Caption displayed below the title of the project on the projects page
   */
  caption?: string
  /**
   * When defined, the period will be displayed as {from} - {to}
   */
  period?: DateRange
  /**[Supports Markdown]
   * Information to summarize a project
   */
  summary?: string
  /**
   * Tags that correspond to project filters on the portfolio page if defined
   */
  tags?: string[]
  /**[Supports Markdown]
   * The title of the project
   */
  title: string
  /**[CSS:background]
   * Background image, repeat, attachment, and position for the project
   */
  thumbnailBackground?: string
  /**[CSS:background-size]
   * Background image size
   */
  thumbnailBackgroundSize?: string
}

/**
 * This concatenates project files for entry within the store.
 */
export type ProjectStoreEntry = {
  /**
   * Content pulled from the projects' markdown (.md) file
   */
  content?: string

  /**
   * Listing information pulled from the projects' yaml (.yml) file
   */
  listing?: ProjectListingInfo
}

/**
 * Defines a filter category in the filters panel
 */
export type ProjectFilterCategory = {
  /**
   * The heading of the category
   */
  heading: string
  /**
   * The filters associated with the category, or more categories
   */
  filters: FilterDefinition[] | ProjectFilterCategory[]
}

/**
 * Defines a filter for a project
 */
export type FilterDefinition = {
  /**
   * The name to display in the filters panel
   */
  displayName: string
  /**
   * The tag which the filter corresponds to for when defined in {@link ProjectListingInfo.tags}
   */
  tag: string
}

/**
 * Whenever a filter is toggled in the filters panel, this holds the data regarding that change
 */
export type FilterChangeEvent = {
  /**
   * The tag that the filter is associated with
   */
  tag: string
  /**
   * The toggle state of the filter
   */
  value: boolean
}

/**
 * Defines the state of the filters panel
 */
export type FilterState = { [tag: string]: boolean }

export type TagDefinition = {
  displayName: string
  className: string
}

export type Tag = 
| TagDefinition
| string

export type ProjectList = {
  projects: { [key: string]: {
    config: string
    content: string
  }}
  filters?: FilterDefinition[] | ProjectFilterCategory[]
}
